@@ -3,13 +3,13 @@
 -- | Extra functions for "Control.Monad".
 --   These functions provide looping, list operations and booleans.
 --   If you need a wider selection of monad loops and list generalisations,
---   see <http://hackage.haskell.org/package/monad-loops monad-loops>.
+--   see <https://hackage.haskell.org/package/monad-loops monad-loops>.
 module Control.Monad.Extra(
     module Control.Monad,
     whenJust, whenJustM,
     whenMaybe, whenMaybeM,
     unit,
-    maybeM, eitherM,
+    maybeM, fromMaybeM, eitherM,
     -- * Loops
     loop, loopM, whileM,
     -- * Lists
@@ -70,6 +70,11 @@ maybeM :: Monad m => m b -> (a -> m b) -> m (Maybe a) -> m b
 maybeM n j x = maybe n j =<< x
 
 
+-- | Monadic generalisation of 'fromMaybe'.
+fromMaybeM :: Monad m => m a -> m (Maybe a) -> m a
+fromMaybeM n x = maybe n pure =<< x
+
+
 -- | Monadic generalisation of 'either'.
 eitherM :: Monad m => (a -> m c) -> (b -> m c) -> m (Either a b) -> m c
 eitherM l r x = either l r =<< x
