@@ -1,10 +1,9 @@
-{-# LANGUAGE CPP, TupleSections, BangPatterns, ConstraintKinds #-}
-{-# OPTIONS_GHC -fno-warn-duplicate-exports #-}
+{-# LANGUAGE TupleSections, BangPatterns, ConstraintKinds #-}
 
 -- | This module extends "Data.List" with extra functions of a similar nature.
 --   The package also exports the existing "Data.List" functions.
 --   Some of the names and semantics were inspired by the
---   <http://hackage.haskell.org/package/text text> package.
+--   <https://hackage.haskell.org/package/text text> package.
 module Data.List.Extra(
     module Data.List,
     -- * String operations
@@ -13,17 +12,19 @@ module Data.List.Extra(
     unescapeHTML, unescapeJSON,
     -- * Splitting
     dropEnd, takeEnd, splitAtEnd, breakEnd, spanEnd,
-    dropWhileEnd, dropWhileEnd', takeWhileEnd,
+    dropWhileEnd', takeWhileEnd,
     stripSuffix, stripInfix, stripInfixEnd,
     dropPrefix, dropSuffix,
     wordsBy, linesBy,
     breakOn, breakOnEnd, splitOn, split, chunksOf,
     -- * Basics
-    notNull, list, uncons, unsnoc, cons, snoc, drop1, mconcatMap,
+    notNull, list, unsnoc, cons, snoc, drop1, mconcatMap,
+    -- * Enum operations
+    enumerate,
     -- * List operations
     groupSort, groupSortOn, groupSortBy,
     nubOrd, nubOrdBy, nubOrdOn,
-    nubOn, groupOn, sortOn,
+    nubOn, groupOn,
     nubSort, nubSortBy, nubSortOn,
     maximumOn, minimumOn,
     disjoint, allSame, anySame,
@@ -57,9 +58,10 @@ repeatedly f as = b : repeatedly f as'
     where (b, as') = f as
 
 
--- | Flipped version of 'map'.
+-- | /DEPRECATED/ Use @flip map@ directly, since this function clashes with @Data.Traversable.for@.
 --
--- > for [1,2,3] (+1) == [2,3,4]
+--   Flipped version of 'map'.
+{-# DEPRECATED for "Use flip map directly, since this function clashes with Data.Traversable.for" #-}
 for :: [a] -> (a -> b) -> [b]
 for = flip map
 
@@ -113,17 +115,6 @@ list :: b -> (a -> [a] -> b) -> [a] -> b
 list nil cons [] = nil
 list nil cons (x:xs) = cons x xs
 
-#if __GLASGOW_HASKELL__ < 709
--- | If the list is empty returns 'Nothing', otherwise returns the 'head' and the 'tail'.
---
--- > uncons "test" == Just ('t',"est")
--- > uncons ""     == Nothing
--- > \xs -> uncons xs == if null xs then Nothing else Just (head xs, tail xs)
-uncons :: [a] -> Maybe (a, [a])
-uncons [] = Nothing
-uncons (x:xs) = Just (x,xs)
-#endif
-
 -- | If the list is empty returns 'Nothing', otherwise returns the 'init' and the 'last'.
 --
 -- > unsnoc "test" == Just ("tes",'t')
@@ -150,6 +141,12 @@ snoc :: [a] -> a -> [a]
 snoc xs x = xs ++ [x]
 
 
+-- | Enumerate all the values of an 'Enum', from 'minBound' to 'maxBound'.
+--
+-- > enumerate == [False, True]
+enumerate :: (Enum a, Bounded a) => [a]
+enumerate = [minBound..maxBound]
+
 -- | Take a number of elements from the end of the list.
 --
 -- > takeEnd 3 "hello"  == "llo"
@@ -285,12 +282,11 @@ line1 = second drop1 . break (== '\n')
 
 -- | Escape a string such that it can be inserted into an HTML document or @\"@ attribute
 --   without any special interpretation. This requires escaping the @<@, @>@, @&@ and @\"@ characters.
---   Note that it does /not/ escape @\'@, so will not work when placed in a @\'@ delimited attribute.
---   Also note that it will escape @\"@ even though that is not required in an HTML body (but is not harmful).
+--   Note that it will escape @\"@ and @\'@ even though that is not required in an HTML body (but is not harmful).
 --
 -- > escapeHTML "this is a test" == "this is a test"
 -- > escapeHTML "<b>\"g&t\"</n>" == "&lt;b&gt;&quot;g&amp;t&quot;&lt;/n&gt;"
--- > escapeHTML "don't" == "don't"
+-- > escapeHTML "t'was another test" == "t&#39;was another test"
 escapeHTML :: String -> String
 escapeHTML = concatMap f
     where
@@ -298,6 +294,7 @@ escapeHTML = concatMap f
         f '<' = "&lt;"
         f '&' = "&amp;"
         f '\"' = "&quot;"
+        f '\'' = "&#39;"
         f x = [x]
 
 -- | Invert of 'escapeHTML' (does not do general HTML unescaping)
@@ -309,6 +306,7 @@ unescapeHTML ('&':xs)
     | Just xs <- stripPrefix "gt;" xs = '>' : unescapeHTML xs
     | Just xs <- stripPrefix "amp;" xs = '&' : unescapeHTML xs
     | Just xs <- stripPrefix "quot;" xs = '\"' : unescapeHTML xs
+    | Just xs <- stripPrefix "#39;" xs = '\'' : unescapeHTML xs
 unescapeHTML (x:xs) = x : unescapeHTML xs
 unescapeHTML [] = []
 
@@ -351,18 +349,6 @@ unescapeJSON (x:xs) = x : unescapeJSON xs
 unescapeJSON [] = []
 
 
-#if __GLASGOW_HASKELL__ < 709
--- | Sort a list by comparing the results of a key function applied to each
--- element.  @sortOn f@ is equivalent to @sortBy (comparing f)@, but has the
--- performance advantage of only evaluating @f@ once for each element in the
--- input list.  This is called the decorate-sort-undecorate paradigm, or
--- Schwartzian transform.
---
--- > sortOn fst [(3,"z"),(1,""),(3,"a")] == [(1,""),(3,"z"),(3,"a")]
-sortOn :: Ord b => (a -> b) -> [a] -> [a]
-sortOn f = map snd . sortBy (compare `on` fst) . map (\x -> let y = f x in y `seq` (y, x))
-#endif
-
 -- | A version of 'group' where the equality is done on some extracted value.
 groupOn :: Eq b => (a -> b) -> [a] -> [[a]]
 groupOn f = groupBy ((==) `on2` f)
@@ -569,12 +555,6 @@ split f (x:xs) | f x = [] : split f xs
 split f (x:xs) | y:ys <- split f xs = (x:y) : ys
 
 
-#if __GLASGOW_HASKELL__ < 704
-dropWhileEnd :: (a -> Bool) -> [a] -> [a]
-dropWhileEnd p = foldr (\x xs -> if p x && null xs then [] else x : xs) []
-#endif
-
-
 -- | A version of 'dropWhileEnd' but with different strictness properties.
 --   The function 'dropWhileEnd' can be used on an infinite list and tests the property
 --   on each character. In contrast, 'dropWhileEnd'' is strict in the spine of the list
@@ -706,7 +686,7 @@ nubOrdBy cmp xs = f E xs
 
 ---------------------------------------------------------------------
 -- OKASAKI RED BLACK TREE
--- Taken from http://www.cs.kent.ac.uk/people/staff/smk/redblack/Untyped.hs
+-- Taken from https://www.cs.kent.ac.uk/people/staff/smk/redblack/Untyped.hs
 
 data Color = R | B deriving Show
 data RB a = E | T Color (RB a) a (RB a) deriving Show
