@@ -3,7 +3,7 @@
 -- | More IO functions. The functions include ones for reading files with specific encodings,
 --   strictly reading files, and writing files with encodings. There are also some simple
 --   temporary file functions, more advanced alternatives can be found in
---   the <http://hackage.haskell.org/package/exceptions exceptions> package.
+--   the <https://hackage.haskell.org/package/exceptions exceptions> package.
 module System.IO.Extra(
     module System.IO,
     captureOutput,
@@ -16,6 +16,7 @@ module System.IO.Extra(
     writeFileEncoding, writeFileUTF8, writeFileBinary,
     -- * Temporary files
     withTempFile, withTempDir, newTempFile, newTempDir,
+    newTempFileWithin, newTempDirWithin,
     -- * File comparison
     fileEq,
     ) where
@@ -103,7 +104,7 @@ writeFileUTF8 = writeFileEncoding utf8
 
 -- | Write a binary file.
 --
--- > \s -> withTempFile $ \file -> do writeFileBinary file s; fmap (== s) $ readFileBinary' file
+-- > \(ASCIIString s) -> withTempFile $ \file -> do writeFileBinary file s; fmap (== s) $ readFileBinary' file
 writeFileBinary :: FilePath -> String -> IO ()
 writeFileBinary file x = withBinaryFile file WriteMode $ \h -> hPutStr h x
 
@@ -158,13 +159,16 @@ tempUnique = atomicModifyIORef tempRef $ succ &&& succ
 --   temporary file. Most users should use 'withTempFile' which
 --   combines these operations.
 newTempFile :: IO (FilePath, IO ())
-newTempFile = do
+newTempFile = newTempFileWithin =<< getTemporaryDirectory
+
+-- | Like 'newTempFile' but using a custom temporary directory.
+newTempFileWithin :: FilePath -> IO (FilePath, IO ())
+newTempFileWithin tmpdir = do
         file <- create
         del <- once $ ignore $ removeFile file
         return (file, del)
     where
         create = do
-            tmpdir <- getTemporaryDirectory
             val <- tempUnique
             (file, h) <- retryBool (\(_ :: IOError) -> True) 5 $ openTempFile tmpdir $ "extra-file-" ++ show val ++ "-"
             hClose h
@@ -189,8 +193,11 @@ withTempFile act = do
 --   temporary directory. Most users should use 'withTempDir' which
 --   combines these operations.
 newTempDir :: IO (FilePath, IO ())
-newTempDir = do
-        tmpdir <- getTemporaryDirectory
+newTempDir = newTempDirWithin =<< getTemporaryDirectory
+
+-- | Like 'newTempDir' but using a custom temporary directory.
+newTempDirWithin :: FilePath -> IO (FilePath, IO ())
+newTempDirWithin tmpdir = do
         dir <- retryBool (\(_ :: IOError) -> True) 5 $ create tmpdir
         del <- once $ ignore $ removeDirectoryRecursive dir
         return (dir, del)
@@ -221,7 +228,7 @@ sameSize h1 h2 = liftM2 (==) (hFileSize h1) (hFileSize h2)
 foreign import ccall unsafe "string.h memcmp" memcmp
     :: Ptr CUChar -> Ptr CUChar -> CSize -> IO CInt
 
--- | Returs 'True' when the contents of both files is the same.
+-- | Returns 'True' when the contents of both files is the same.
 sameContent :: Handle -> Handle -> IO Bool
 sameContent h1 h2 = sameSize h1 h2 &&^ withb (\b1 -> withb $ \b2 -> eq b1 b2)
     where eq b1 b2 = do
