@@ -1,4 +1,4 @@
-{-# LANGUAGE ScopedTypeVariables, CPP, FlexibleInstances #-}
+{-# LANGUAGE ScopedTypeVariables, FlexibleInstances #-}
 {-# OPTIONS_GHC -fno-warn-orphans #-} -- OK because a test module
 
 module TestUtil
@@ -11,7 +11,6 @@ module TestUtil
     ) where
 
 import Test.QuickCheck
-import Test.QuickCheck.Test
 import System.IO.Unsafe
 import Text.Show.Functions()
 
@@ -23,7 +22,8 @@ import Data.Char as X
 import Data.Either.Extra as X
 import Data.Function as X
 import Data.IORef.Extra as X
-import Data.List.Extra as X
+import Data.List.Extra as X hiding (union, unionBy)
+import Data.List.NonEmpty.Extra as X (NonEmpty(..), (|>), (|:), appendl, appendr, union, unionBy)
 import Data.Monoid as X
 import Data.Tuple.Extra as X
 import Data.Typeable.Extra as X
@@ -44,7 +44,9 @@ testCount = unsafePerformIO $ newIORef 0
 testGen :: Testable prop => String -> prop -> IO ()
 testGen msg prop = testRaw msg $ do
     r <- quickCheckResult prop
-    unless (isSuccess r) $ error "Test failed"
+    case r of
+        Success{} -> return ()
+        _ -> errorIO "Test failed"
 
 testRaw :: String -> IO () -> IO ()
 testRaw msg test = do
@@ -64,11 +66,6 @@ a ==== b
     | a == b = True
     | otherwise = error $ "Not equal!\n" ++ show a ++ "\n" ++ show b
 
-#if __GLASGOW_HASKELL__ < 707
-instance Eq ErrorCall where
-    ErrorCall x == ErrorCall y = x == y
-#endif
-
 runTests :: IO () -> IO ()
 runTests t = do
     -- ensure that capturing output is robust
